@@ -4,5 +4,5 @@
  */
 CKEDITOR.plugins.setLang( 'widget', 'de-ch', {
 	'move': 'Zum Verschieben anwählen und ziehen',
-	'label': '%1 widget' // MISSING
+	'label': '%1 Steuerelement'
 } );
